@@ -32,7 +32,7 @@ Dialog::Dialog(QWidget *parent) :
 
 
   this->setWindowTitle("Edit note");
-  this->setWindowModality(Qt::ApplicationModal);
+ // this->setWindowModality(Qt::ApplicationModal);
   ui->teMain->setFrameShadow(QFrame::Plain);
   ui->teMain->setFrameShape(QFrame::NoFrame);
   ui->teMain->setPalette(QPalette(cltextedit,cldefault,cldefault,cltextedit,cltextedit,cltextedit,cldefault,cldefault,cldefault));
@@ -61,12 +61,12 @@ Dialog::Dialog(QWidget *parent) :
   ui->teMain->setText(oSettings->value("note","").toString());
 
 
-  delete oSettings;
+  //delete oSettings;
 }
 
 Dialog::~Dialog()
 {
-    delete ui;
+    //delete ui;
 }
 
 void Dialog::changeEvent(QEvent *e)
